@@ -3,7 +3,6 @@ from django.core import management
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models.manager import Manager
 from django.test.testcases import TestCase
-
 from moderation.register import ModerationManager, RegistrationError
 from moderation.moderator import GenericModerator
 from moderation.managers import ModerationObjectsManager
@@ -11,13 +10,12 @@ from moderation.models import ModeratedObject, MODERATION_STATUS_APPROVED
 from moderation.signals import pre_moderation, post_moderation
 from tests.models import UserProfile, \
     ModelWithSlugField, ModelWithSlugField2, ModelWithMultipleManagers
-from django.test.testcases import TestCase
 from tests.utils import setup_moderation
 from tests.utils import teardown_moderation
 from moderation.helpers import import_moderator
 from tests.models import Book
 
-from django.db import IntegrityError
+from django.db import IntegrityError, transaction
 
 
 class RegistrationTestCase(TestCase):
@@ -69,6 +67,9 @@ class RegistrationTestCase(TestCase):
             when existing object is saved, when getting of object returns 
             old version of object"""
         profile = UserProfile.objects.get(user__username='moderator')
+        moderated_object = ModeratedObject(content_object=profile)
+        moderated_object.save()
+        moderated_object.approve(moderated_by=self.user)
 
         profile.description = "New description"
         profile.save()
@@ -177,7 +178,12 @@ class IntegrityErrorTestCase(TestCase):
                           slug='test')
 
         m2 = ModelWithSlugField(slug='test')
-        self.assertRaises(IntegrityError, m2.save)
+
+        if hasattr(transaction, 'atomic'):
+            with transaction.atomic():
+                self.assertRaises(IntegrityError, m2.save)
+        else:
+            self.assertRaises(IntegrityError, m2.save)
 
         self.assertEqual(ModeratedObject.objects.all().count(), 1)
 
@@ -188,7 +194,11 @@ class IntegrityErrorTestCase(TestCase):
         m1 = ModelWithSlugField2.objects.get(slug='test')
 
         m2 = ModelWithSlugField2(slug='test')
-        self.assertRaises(IntegrityError, m2.save)
+        if hasattr(transaction, 'atomic'):
+            with transaction.atomic():
+                self.assertRaises(IntegrityError, m2.save)
+        else:
+            self.assertRaises(IntegrityError, m2.save)
 
         self.assertEqual(ModeratedObject.objects.all().count(), 0)
 
@@ -231,7 +241,11 @@ class IntegrityErrorRegressionTestCase(TestCase):
         m1.save()
 
         m2 = ModelWithSlugField(slug='test')
-        self.assertRaises(IntegrityError, m2.save)
+        if hasattr(transaction, 'atomic'):
+            with transaction.atomic():
+                self.assertRaises(IntegrityError, m2.save)
+        else:
+            self.assertRaises(IntegrityError, m2.save)
 
         self.assertEqual(ModeratedObject.objects.all().count(), 1)
 
@@ -289,7 +303,6 @@ class ModerationManagerTestCase(TestCase):
     def test_save_new_instance_after_add_and_remove_fields_from_class(self):
         """Test if after removing moderation from model class new 
         instance of model can be created"""
-        from django.db.models import signals
 
         class CustomManager(Manager):
             pass
@@ -322,7 +335,7 @@ class ModerationManagerTestCase(TestCase):
                          repr(manager.__class__))
         self.assertEqual(hasattr(UserProfile, 'moderated_object'), True)
 
-        #clean up
+        # clean up
         self.moderation._remove_fields(moderator)
 
     def test_get_or_create_moderated_object_exist(self):
@@ -421,8 +434,7 @@ class ModerationSignalsTestCase(TestCase):
             notify_moderator = False
 
         self.moderation = setup_moderation(
-            [(UserProfile, UserProfileModerator)]
-        )
+            [(UserProfile, UserProfileModerator)])
 
         self.moderation._disconnect_signals(UserProfile)
 
@@ -509,7 +521,9 @@ class ModerationSignalsTestCase(TestCase):
         signals.post_save.connect(self.moderation.post_save_handler,
                                   sender=UserProfile)
         profile = UserProfile.objects.get(user__username='moderator')
-        ModeratedObject(content_object=profile).save()
+        moderated_object = ModeratedObject(content_object=profile)
+        moderated_object.save()
+        moderated_object.approve(moderated_by=self.user)
 
         profile.description = 'New description of user profile'
         profile.save()
