@@ -12,6 +12,5 @@ urlpatterns = patterns(
     '',
     (r'^admin/', include(admin.site.urls)),
     (r'^media/(?P<path>.*)$', 'django.views.static.serve', {
-        'document_root': settings.MEDIA_ROOT
-    }),
+        'document_root': settings.MEDIA_ROOT}),
 )
