@@ -1,4 +1,7 @@
-from django.conf.urls.defaults import patterns, include, handler500
+try:
+    from django.conf.urls.defaults import patterns, include, handler500
+except ImportError:
+    from django.conf.urls import patterns, include, handler500
 from django.conf import settings
 from django.contrib import admin
 
@@ -10,6 +13,5 @@ urlpatterns = patterns(
     '',
     (r'^admin/', include(admin.site.urls)),
     (r'^media/(?P<path>.*)$', 'django.views.static.serve', {
-        'document_root': settings.MEDIA_ROOT
-    }),
+        'document_root': settings.MEDIA_ROOT}),
 )
